@@ -26,8 +26,11 @@ __copyright__ = """
 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 """
 
-__version__ = "2020.11.13"
+__version__ = "2020.11.30"
 
 repo_root = pathlib.Path(__file__).parent
 install_requires = (repo_root / "requirements.txt").read_text(encoding="utf-8").split('\n')
-extras_require = {'schema': ['lxml>=4.6.1'], 'all': ['lxml>=4.6.1']}
+extras_require = {
+		"testing": ["pytest>=6.0.0", "domdf-python-tools[testing]>=1.5.0"],
+		"all": ["domdf-python-tools[testing]>=1.5.0", "pytest>=6.0.0"]
+		}
