@@ -31,6 +31,7 @@ from typing import Iterable, Optional, Sequence, Union
 # 3rd party
 from domdf_python_tools.compat import importlib_resources
 from domdf_python_tools.paths import PathPlus
+from domdf_python_tools.stringlist import DelimitedList, StringList
 from jinja2 import BaseLoader, Environment, StrictUndefined, Template
 from typing_extensions import Literal
 
@@ -52,7 +53,7 @@ __all__ = [
 		]
 
 #: Regular expression to match the installation block placeholder.
-installation_regex = re.compile(r"(?s)(\.\. start installation)(.*?)(\.\. end installation)")
+installation_regex = re.compile(r"(?s)(\.\. start installation)(.*?)(\.\. end installation)\n")
 
 #: Regular expression to match the shields block placeholder.
 shields_regex = re.compile(r"(?s)(\.\. start shields)(.*?)(\.\. end shields)")
@@ -98,7 +99,7 @@ def get_shields_block_template() -> Template:
 			make_maintained_shield=shields.make_maintained_shield,
 			make_rtfd_shield=shields.make_rtfd_shield,
 			make_docs_check_shield=shields.make_docs_check_shield,
-			make_travis_shield=shields.make_travis_shield,
+			make_actions_linux_shield=shields.make_actions_linux_shield,
 			make_actions_windows_shield=shields.make_actions_windows_shield,
 			make_actions_macos_shield=shields.make_actions_macos_shield,
 			make_requires_shield=shields.make_requires_shield,
@@ -137,7 +138,7 @@ def get_docs_shields_block_template() -> Template:
 			make_maintained_shield=_docs_shields.make_docs_maintained_shield,
 			make_rtfd_shield=_docs_shields.make_docs_rtfd_shield,
 			make_docs_check_shield=_docs_shields.make_docs_docs_check_shield,
-			make_travis_shield=_docs_shields.make_docs_travis_shield,
+			make_actions_linux_shield=_docs_shields.make_docs_actions_linux_shield,
 			make_actions_windows_shield=_docs_shields.make_docs_actions_windows_shield,
 			make_actions_macos_shield=_docs_shields.make_docs_actions_macos_shield,
 			make_requires_shield=_docs_shields.make_docs_requires_shield,
@@ -231,7 +232,7 @@ def create_shields_block(
 	:return: The shields block created from the above settings.
 	"""
 
-	if unique_name and not unique_name.startswith("_"):
+	if unique_name and not unique_name.startswith('_'):
 		unique_name = f"_{unique_name}"
 
 	if not pypi_name:
@@ -246,7 +247,6 @@ def create_shields_block(
 			tests=tests,
 			conda=conda,
 			docs=docs,
-			travis_site=travis_site,
 			pypi_name=pypi_name,
 			version=version,
 			unique_name=unique_name,
@@ -342,15 +342,25 @@ def create_docs_install_block(
 	if not pypi_name:
 		pypi_name = repo_name
 
-	if conda_channels is None:
-		conda_channels = []
+	conda_channels = DelimitedList(conda_channels or [])
 
-	return get_docs_installation_block_template().render(
-			conda=conda,
-			pypi=pypi,
-			pypi_name=pypi_name,
-			conda_channels=", ".join(conda_channels),
-			)
+	block = StringList([".. start installation", '', f".. installation:: {pypi_name}"])
+
+	with block.with_indent_size(1):
+
+		if pypi:
+			block.append(":pypi:")
+
+		block.append(":github:")
+
+		if conda:
+			block.append(":anaconda:")
+			block.append(f":conda-channels: {conda_channels:, }")
+
+	block.blankline()
+	block.append(".. end installation")
+
+	return str(block)
 
 
 @functools.lru_cache(20)
