@@ -28,19 +28,21 @@ import datetime
 import pathlib
 import posixpath
 import sys
-from typing import List, Optional
+from typing import List, Optional, Sequence
 
 # 3rd party
 import click
 import jinja2
+import requests
 from apeye.requests_url import RequestsURL
+from consolekit.options import force_option
 from domdf_python_tools.paths import PathPlus, maybe_make
 from domdf_python_tools.stringlist import StringList
 from jinja2 import BaseLoader, Environment, StrictUndefined
+from southwark.click import commit_message_option, commit_option
 
 # this package
 from repo_helper.cli import cli_command
-from repo_helper.cli.options import commit_message_option, commit_option, force_option
 from repo_helper.cli.utils import run_repo_helper
 from repo_helper.templates import init_repo_template_dir
 
@@ -139,24 +141,12 @@ def init_repo(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[st
 		(repo_path / templates.globals["tests_dir"] / "requirements.txt").touch()
 
 	# docs
+	docs_files: Sequence[str]
+
 	if templates.globals["enable_docs"]:
-		docs_dir = repo_path / templates.globals["docs_dir"]
-		docs_dir.maybe_make()
-		(docs_dir / "api").maybe_make()
-
-		for filename in {"index.rst"}:
-			template = init_repo_templates.get_template(filename)
-			(docs_dir / filename).write_clean(template.render())
-
-		api_buf = StringList()
-		api_buf.append('=' * (len(templates.globals["import_name"]) + 1))
-		api_buf.append(templates.globals["import_name"])
-		api_buf.append('=' * (len(templates.globals["import_name"]) + 1))
-		api_buf.blankline(ensure_single=True)
-		api_buf.append(f".. automodule:: {templates.globals['import_name']}")
-		api_buf.blankline(ensure_single=True)
-
-		(docs_dir / "api" / templates.globals["modname"]).with_suffix(".rst").write_lines(api_buf)
+		docs_files = enable_docs(repo_path, templates, init_repo_templates)
+	else:
+		docs_files = ()
 
 	# other
 	for filename in {"README.rst"}:
@@ -177,9 +167,18 @@ def init_repo(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[st
 		license_url = base_license_url / "apache.txt"
 
 	if license_url is not None:
-		response = license_url.get()
-		if response.status_code == 200:
-			license_text = response.text
+		for attempt in [1, 2]:
+
+			try:
+				response = license_url.get()
+			except requests.exceptions.RequestException:
+				if attempt == 1:
+					continue
+				else:
+					raise
+
+			if response.status_code == 200:
+				license_text = response.text
 
 	license_template = Environment(  # nosec: B701
 			loader=BaseLoader(),
@@ -200,10 +199,38 @@ def init_repo(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[st
 	return [
 			posixpath.join(templates.globals["import_name"], "__init__.py"),
 			posixpath.join(templates.globals["tests_dir"], "__init__.py"),
-			posixpath.join(templates.globals["docs_dir"], "api", f"{templates.globals['modname']}.rst"),
-			posixpath.join(templates.globals["docs_dir"], "index.rst"),
+			*docs_files,
 			posixpath.join(templates.globals["tests_dir"], "requirements.txt"),
 			"requirements.txt",
 			"LICENSE",
 			"README.rst",
 			]
+
+
+def enable_docs(
+		repo_path: pathlib.Path,
+		templates: jinja2.Environment,
+		init_repo_templates: jinja2.Environment,
+		) -> List[str]:
+	docs_dir = repo_path / templates.globals["docs_dir"]
+	docs_dir.maybe_make()
+	(docs_dir / "api").maybe_make()
+
+	for filename in {"index.rst"}:
+		template = init_repo_templates.get_template(filename)
+		(docs_dir / filename).write_clean(template.render())
+
+	api_buf = StringList()
+	api_buf.append('=' * (len(templates.globals["import_name"]) + 1))
+	api_buf.append(templates.globals["import_name"])
+	api_buf.append('=' * (len(templates.globals["import_name"]) + 1))
+	api_buf.blankline(ensure_single=True)
+	api_buf.append(f".. automodule:: {templates.globals['import_name']}")
+	api_buf.blankline(ensure_single=True)
+
+	(docs_dir / "api" / templates.globals["modname"]).with_suffix(".rst").write_lines(api_buf)
+
+	return [
+			posixpath.join(templates.globals["docs_dir"], "api", f"{templates.globals['modname']}.rst"),
+			posixpath.join(templates.globals["docs_dir"], "index.rst"),
+			]
