@@ -30,6 +30,7 @@ from typing import Any, Dict, Iterable, List, Optional, Union
 # 3rd party
 from configconfig.configvar import ConfigVar
 from configconfig.utils import optional_getter
+from natsort import natsorted  # type: ignore
 from packaging.version import Version
 from shippinglabel.classifiers import validate_classifiers
 
@@ -55,7 +56,8 @@ __all__ = [
 		"source_dir",
 		"pure_python",
 		"on_pypi",
-		"stubs_package"
+		"stubs_package",
+		"assignee"
 		]
 
 
@@ -108,6 +110,27 @@ class username(ConfigVar):  # noqa
 	category: str = "metadata"
 
 
+class assignee(ConfigVar):  # noqa
+	"""
+	The username of the GitHub account to assign issues to.
+
+	Defaults to :conf:`username` if unset.
+
+	Example:
+
+	.. code-block:: yaml
+
+		username: repo-helper
+		assignee: domdfcoding
+
+	.. versionadded:: 2020.11.23
+	"""
+
+	dtype = str
+	default = username
+	category: str = "metadata"
+
+
 class modname(ConfigVar):  # noqa
 	"""
 	The name of the package.
@@ -241,8 +264,7 @@ class import_name(ConfigVar):  # noqa
 			return cls.validator(cls.validate(raw_config_vars))
 
 	@classmethod
-	def validate(cls, raw_config_vars: Optional[Dict[str, Any]] = None):
-
+	def validate(cls, raw_config_vars: Optional[Dict[str, Any]] = None):  # noqa: D102
 		if raw_config_vars is None:
 			raw_config_vars = {}
 
@@ -262,19 +284,28 @@ class import_name(ConfigVar):  # noqa
 			return cls.rtype(obj)
 
 	@classmethod
-	def validator(cls, name: str) -> str:
-		name = name.replace("-", "_")  # replace hyphens with underscores
-		name = name.replace("/", ".")
-		for part in name.split("."):
+	def validator(cls, name: str) -> str:  # noqa: D102
+		name = name.replace('-', '_')  # replace hyphens with underscores
+		name = name.replace('/', '.')
+		for part in name.split('.'):
 			if not part.isidentifier():
-				raise ValueError(
-						"""\
-	'import_name' must only contain contains letters, numbers, underscores and fullstops.
-	It cannot cannot start with a number, or contain any spaces."""
-						)
+				raise InvalidName()
+
 		return name
 
 
+class InvalidName(SyntaxError):
+	"""
+	Error raised when an invalid value is given for :conf:`import_name`.
+	"""
+
+	def __init__(self):
+		super().__init__(
+				"'import_name' must only contain contains letters, numbers, underscores and fullstops.\n"
+				"It cannot cannot start with a number, or contain any spaces."
+				)
+
+
 class classifiers(ConfigVar):  # noqa
 	"""
 	A list of `"trove classifiers" <https://pypi.org/classifiers/>`_ for PyPI.
@@ -294,7 +325,7 @@ class classifiers(ConfigVar):  # noqa
 	category: str = "metadata"
 
 	@classmethod
-	def validate(cls, raw_config_vars: Optional[Dict[str, Any]] = None):
+	def validate(cls, raw_config_vars: Optional[Dict[str, Any]] = None):  # noqa: D102
 
 		# this package
 		from repo_helper.configuration import python_versions
@@ -346,7 +377,7 @@ class classifiers(ConfigVar):  # noqa
 
 		validate_classifiers(classifier_list)
 
-		return sorted(classifier_list)
+		return natsorted(classifier_list)
 
 
 class keywords(ConfigVar):  # noqa
@@ -386,8 +417,8 @@ class license(ConfigVar):  # noqa  # pylint: disable=redefined-builtin
 	category: str = "metadata"
 
 	@classmethod
-	def validator(cls, value):
-		value = value.replace(" ", '')
+	def validator(cls, value):  # noqa: D102
+		value = value.replace(' ', '')
 
 		if value in license_lookup:
 			value = license_lookup[value]
@@ -430,7 +461,7 @@ class source_dir(ConfigVar):  # noqa
 	category: str = "metadata"
 
 	@classmethod
-	def validator(cls, value: str) -> str:
+	def validator(cls, value: str) -> str:  # noqa: D102
 		return os.path.join(value, '')
 
 
