@@ -27,6 +27,9 @@ Configuration utilities.
 import pathlib
 from typing import Any, Dict, Iterable, List, Mapping, Tuple
 
+# 3rd party
+from natsort import natsorted  # type: ignore
+
 __all__ = [
 		"get_tox_python_versions",
 		"get_tox_travis_python_versions",
@@ -46,7 +49,7 @@ def get_tox_python_versions(python_versions: Iterable[str]) -> List[str]:
 	tox_py_versions = []
 
 	for py_version in python_versions:
-		py_version = str(py_version).replace(".", '')
+		py_version = str(py_version).replace('.', '')
 		if not py_version.startswith("py"):
 			py_version = f"py{py_version}"
 		tox_py_versions.append(py_version)
@@ -54,12 +57,12 @@ def get_tox_python_versions(python_versions: Iterable[str]) -> List[str]:
 	return tox_py_versions
 
 
-def get_tox_travis_python_versions(
+def get_gh_actions_python_versions(
 		python_versions: Iterable[str],
 		tox_py_versions: Iterable[str],
 		) -> Dict[str, str]:
 	"""
-	Prepares the mapping of Python versions to tox testenvs for use with Travis.
+	Prepares the mapping of Python versions to tox testenvs for use with GitHub Actions.
 
 	:param python_versions: List of Python versions to run tests for.
 	:param tox_py_versions: The list of tox testenvs for the Python versions.
@@ -73,24 +76,7 @@ def get_tox_travis_python_versions(
 	return tox_travis_matrix
 
 
-def get_gh_actions_python_versions(
-		python_versions: Iterable[str],
-		tox_py_versions: Iterable[str],
-		) -> Dict[str, str]:
-	"""
-	Prepares the mapping of Python versions to tox testenvs for use with GitHub actions.
-
-	:param python_versions: List of Python versions to run tests for.
-	:param tox_py_versions: The list of tox testenvs for the Python versions.
-	"""
-
-	tox_travis_matrix: Dict[str, str] = {}
-
-	for py_version, tox_py_version in zip(python_versions, tox_py_versions):
-		if tox_py_version != "docs":
-			tox_travis_matrix[str(py_version)] = f"{tox_py_version}, build"
-
-	return tox_travis_matrix
+get_tox_travis_python_versions = get_gh_actions_python_versions
 
 
 def get_version_classifiers(python_versions: Iterable[str]) -> List[str]:
@@ -107,7 +93,7 @@ def get_version_classifiers(python_versions: Iterable[str]) -> List[str]:
 	for py_version in python_versions:
 		py_version = str(py_version)
 
-		if py_version.startswith("3"):
+		if py_version.startswith('3'):
 			py_version = py_version.replace("-dev", '')
 			for classifier in (
 					f"Programming Language :: Python :: {py_version}",
@@ -122,7 +108,7 @@ def get_version_classifiers(python_versions: Iterable[str]) -> List[str]:
 	version_classifiers.append("Programming Language :: Python")
 	version_classifiers.append("Programming Language :: Python :: 3 :: Only")
 
-	return sorted(set(version_classifiers))
+	return natsorted(set(version_classifiers))
 
 
 def parse_extras(raw_config_vars: Mapping[str, Any], repo_path: pathlib.Path) -> Tuple[Dict, List[str]]:
@@ -145,7 +131,7 @@ def parse_extras(raw_config_vars: Mapping[str, Any], repo_path: pathlib.Path) ->
 			if (repo_path / requires).is_file():
 				# a path to the requirements file from the repo root
 				extras_require[extra] = [
-						x for x in (repo_path / requires).read_text(encoding="UTF-8").split("\n") if x
+						x for x in (repo_path / requires).read_text(encoding="UTF-8").split('\n') if x
 						]
 				if requires not in additional_requirements_files:
 					additional_requirements_files.append(requires)
@@ -153,7 +139,7 @@ def parse_extras(raw_config_vars: Mapping[str, Any], repo_path: pathlib.Path) ->
 				# A single requirement
 				extras_require[extra] = [requires]
 
-		all_extras += [x.replace(" ", '') for x in extras_require[extra]]
+		all_extras += [x.replace(' ', '') for x in extras_require[extra]]
 
 	all_extras = sorted(set(all_extras))
 
