@@ -30,6 +30,7 @@ from typing import List
 # 3rd party
 import jinja2
 from domdf_python_tools.paths import PathPlus
+from domdf_python_tools.stringlist import DelimitedList, StringList
 
 # this package
 from repo_helper.configupdater2 import ConfigUpdater
@@ -37,79 +38,19 @@ from repo_helper.files import management
 from repo_helper.utils import no_dev_versions
 
 __all__ = [
-		"make_travis",
-		"remove_copy_pypi_2_github",
-		"make_make_conda_recipe",
-		"make_travis_deploy_conda",
 		"make_github_ci",
 		"make_github_docs_test",
 		"make_github_octocheese",
+		"make_github_flake8",
 		"make_github_manylinux",
 		"ensure_bumpversion",
+		"make_actions_deploy_conda",
+		"make_conda_actions_ci",
 		]
 
 
-@management.register("travis")
-def make_travis(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
-	"""
-	Add configuration for ``Travis-CI`` to the desired repo.
-
-	https://travis-ci.com/
-
-	:param repo_path: Path to the repository root.
-	:param templates:
-	"""
-
-	# TODO: Use travis matrix rather than tox-travis; see humanity for example
-
-	if templates.globals["pure_python"]:
-		travis = templates.get_template("travis.yml")
-	else:
-		travis = templates.get_template("travis_not_pure_python.yml")
-
-	python_versions = templates.globals["python_versions"]
-	no_dev_versions_ = no_dev_versions(python_versions)
-	dev_versions = [v for v in python_versions if v not in no_dev_versions_]
-
-	PathPlus(repo_path / ".travis.yml").write_clean(travis.render(dev_versions=dev_versions))
-
-	return [".travis.yml"]
-
-
-@management.register("copy_pypi_2_github", ["enable_releases"])
-def remove_copy_pypi_2_github(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
-	"""
-	Remove deprecated copy_pypi_2_github.py script.
-
-	Uue octocheese and its GitHub Action instead.
-
-	:param repo_path: Path to the repository root.
-	:param templates:
-	"""
-
-	copier = PathPlus(repo_path / ".ci" / "copy_pypi_2_github.py")
-	if copier.is_file():
-		copier.unlink()
-
-	return [copier.relative_to(repo_path).as_posix()]
-
-
-@management.register("make_conda_recipe", ["enable_conda"])
-def make_make_conda_recipe(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
-	"""
-	Add script to create a Conda recipe for the package.
-
-	:param repo_path: Path to the repository root.
-	:param templates:
-	"""
-
-	file = PathPlus(repo_path / "make_conda_recipe.py")
-	file.write_clean(templates.get_template("make_conda_recipe._py").render())
-	return [file.name]
-
-
-@management.register("travis_deploy_conda", ["enable_conda"])
-def make_travis_deploy_conda(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
+@management.register("actions_deploy_conda", ["enable_conda"])
+def make_actions_deploy_conda(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
 	"""
 	Add script to build Conda package and deploy to Anaconda.
 
@@ -117,13 +58,26 @@ def make_travis_deploy_conda(repo_path: pathlib.Path, templates: jinja2.Environm
 	:param templates:
 	"""
 
-	file = PathPlus(repo_path / ".ci" / "travis_deploy_conda.sh")
-	file.parent.maybe_make()
+	old_deploy_file = PathPlus(repo_path / ".ci" / "actions_deploy_conda.sh")
+	old_build_file = PathPlus(repo_path / ".ci" / "actions_build_conda.sh")
+	old_deploy_file.unlink(missing_ok=True)
+	old_build_file.unlink(missing_ok=True)
 
-	file.write_clean(templates.get_template(file.name).render())
-	file.make_executable()
+	deploy_file = PathPlus(repo_path / ".github" / "actions_deploy_conda.sh")
+	build_file = PathPlus(repo_path / ".github" / "actions_build_conda.sh")
+	deploy_file.parent.maybe_make()
 
-	return [file.relative_to(repo_path).as_posix()]
+	build_file.write_clean(templates.get_template(build_file.name).render())
+	build_file.make_executable()
+	deploy_file.write_clean(templates.get_template(deploy_file.name).render())
+	deploy_file.make_executable()
+
+	return [
+			build_file.relative_to(repo_path).as_posix(),
+			old_build_file.relative_to(repo_path).as_posix(),
+			deploy_file.relative_to(repo_path).as_posix(),
+			old_deploy_file.relative_to(repo_path).as_posix(),
+			]
 
 
 @management.register("actions")
@@ -146,6 +100,13 @@ def make_github_ci(repo_path: pathlib.Path, templates: jinja2.Environment) -> Li
 	macos_ci_file = workflows_dir / "python_ci_macos.yml"
 	linux_ci_file = workflows_dir / "python_ci_linux.yml"
 
+	standard_python_install_lines = [
+			"python -VV",
+			"python -m site",
+			"python -m pip install --upgrade pip setuptools wheel",
+			"python -m pip install --upgrade tox tox-gh-actions virtualenv",
+			]
+
 	if "Windows" in templates.globals["platforms"]:
 		py_versions = templates.globals["python_versions"][:]
 		if not templates.globals["pure_python"] and "3.8" in py_versions:
@@ -155,34 +116,60 @@ def make_github_ci(repo_path: pathlib.Path, templates: jinja2.Environment) -> Li
 			# https://github.com/domdfcoding/flake8-sphinx-links/runs/1276871725?check_suite_focus=true
 			py_versions.remove("pypy3")
 
+		dependency_lines = StringList(standard_python_install_lines)
+		if templates.globals["travis_additional_requirements"]:
+			travis_additional_requirements = DelimitedList(templates.globals["travis_additional_requirements"])
+			dependency_lines.append(f"python -m pip install --upgrade {travis_additional_requirements: }")
+
 		windows_ci_file.write_clean(
 				actions.render(
 						no_dev_versions=no_dev_versions,
 						ci_platform="windows-2019",
 						ci_name="Windows Tests",
 						python_versions=py_versions,
+						dependency_lines=dependency_lines,
 						)
 				)
 	elif windows_ci_file.is_file():
 		windows_ci_file.unlink()
 
 	if "macOS" in templates.globals["platforms"]:
+
+		dependency_lines = StringList(standard_python_install_lines)
+		if templates.globals["travis_additional_requirements"]:
+			travis_additional_requirements = DelimitedList(templates.globals["travis_additional_requirements"])
+			dependency_lines.append(f"python -m pip install --upgrade {travis_additional_requirements: }")
+
 		macos_ci_file.write_clean(
 				actions.render(
 						no_dev_versions=no_dev_versions,
 						ci_platform="macos-latest",
 						ci_name="macOS Tests",
+						dependency_lines=dependency_lines,
 						)
 				)
 	elif macos_ci_file.is_file():
 		macos_ci_file.unlink()
 
-	if "Linux" in templates.globals["platforms"] and not templates.globals["pure_python"]:
+	if "Linux" in templates.globals["platforms"]:
+		dependency_lines = StringList(templates.globals["travis_extra_install_pre"])
+		dependency_lines.extend(standard_python_install_lines)
+
+		if templates.globals["enable_tests"]:
+			dependency_lines.append("python -m pip install --upgrade coverage_pyver_pragma")
+
+		if templates.globals["travis_additional_requirements"]:
+			travis_additional_requirements = DelimitedList(templates.globals["travis_additional_requirements"])
+			dependency_lines.append(f"python -m pip install --upgrade {travis_additional_requirements: }")
+
+		dependency_lines.extend(templates.globals["travis_extra_install_post"])
+
 		linux_ci_file.write_clean(
 				actions.render(
 						no_dev_versions=no_dev_versions,
 						ci_platform="ubuntu-18.04",
 						ci_name="Linux Tests",
+						dependency_lines=dependency_lines,
 						)
 				)
 	elif linux_ci_file.is_file():
@@ -204,23 +191,26 @@ def make_conda_actions_ci(repo_path: pathlib.Path, templates: jinja2.Environment
 	:param templates:
 	"""
 
-	actions = templates.get_template("github_conda_ci.yml")
-
 	workflows_dir = PathPlus(repo_path / ".github" / "workflows")
-	workflows_dir.maybe_make(parents=True)
-
 	conda_ci_file = workflows_dir / "conda_ci.yml"
 
-	def no_pypy_versions(versions):
-		"""
-		Returns the subset of ``versions`` which does not end with ``-dev``.
+	if templates.globals["enable_conda"]:
+		actions = templates.get_template("github_conda_ci.yml")
+		workflows_dir.maybe_make(parents=True)
 
-		:param versions:
-		"""
+		def no_pypy_versions(versions):
+			"""
+			Returns the subset of ``versions`` which does not end with ``-dev``.
 
-		return [v for v in no_dev_versions(versions) if "pypy" not in v.lower()]
+			:param versions:
+			"""
 
-	conda_ci_file.write_clean(actions.render(no_dev_versions=no_pypy_versions))
+			return [v for v in no_dev_versions(versions) if "pypy" not in v.lower()]
+
+		conda_ci_file.write_clean(actions.render(no_dev_versions=no_pypy_versions))
+
+	else:
+		conda_ci_file.unlink(missing_ok=True)
 
 	return [conda_ci_file.relative_to(repo_path).as_posix()]
 
@@ -234,6 +224,8 @@ def make_github_manylinux(repo_path: pathlib.Path, templates: jinja2.Environment
 	:param templates:
 	"""
 
+	# TODO: deploys from other supported platforms for not pure python
+
 	file = PathPlus(repo_path / ".github" / "workflows" / "manylinux_build.yml")
 	file.parent.maybe_make(parents=True)
 
@@ -254,7 +246,7 @@ def make_github_manylinux(repo_path: pathlib.Path, templates: jinja2.Environment
 
 		file.write_clean(actions.render(
 				wheel_py_versions=wheel_py_versions,
-				PYVERSIONS=" ".join(PYVERSIONS),
+				PYVERSIONS=' '.join(PYVERSIONS),
 				))
 	elif file.is_file():
 		file.unlink()
@@ -265,7 +257,7 @@ def make_github_manylinux(repo_path: pathlib.Path, templates: jinja2.Environment
 @management.register("docs_action", ["enable_docs"])
 def make_github_docs_test(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
 	"""
-	Add configuration for `Github Actions` documentation check to the desired repo.
+	Add configuration for Github Actions documentation check to the desired repo.
 
 	:param repo_path: Path to the repository root.
 	:param templates:
@@ -280,7 +272,7 @@ def make_github_docs_test(repo_path: pathlib.Path, templates: jinja2.Environment
 @management.register("octocheese")
 def make_github_octocheese(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
 	"""
-	Add configuration for the OctoCheese `Github Action`.
+	Add configuration for the OctoCheese Github Action.
 
 	:param repo_path: Path to the repository root.
 	:param templates:
@@ -297,6 +289,23 @@ def make_github_octocheese(repo_path: pathlib.Path, templates: jinja2.Environmen
 	return [file.relative_to(repo_path).as_posix()]
 
 
+@management.register("flake8_action")
+def make_github_flake8(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
+	"""
+	Add configuration for the Flake8 Github Action.
+
+	:param repo_path: Path to the repository root.
+	:param templates:
+	"""
+
+	file = PathPlus(repo_path / ".github" / "workflows" / "flake8.yml")
+	file.parent.maybe_make(parents=True)
+
+	file.write_clean(templates.get_template(file.name).render())
+
+	return [file.relative_to(repo_path).as_posix()]
+
+
 @management.register("bumpversion")
 def ensure_bumpversion(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
 	"""
