@@ -31,7 +31,9 @@ import logging
 import os.path
 import pathlib
 import shutil
-from typing import Dict, List, Sequence, Set, Union
+import warnings
+from textwrap import dedent
+from typing import Dict, List, Sequence, Union
 
 # 3rd party
 import css_parser  # type: ignore
@@ -42,9 +44,13 @@ from domdf_python_tools.compat import importlib_resources
 from domdf_python_tools.paths import PathPlus
 from domdf_python_tools.typing import PathLike
 from domdf_python_tools.utils import enquote_value
-from packaging.requirements import Requirement
 from shippinglabel import normalize
-from shippinglabel.requirements import RequirementsManager, combine_requirements, read_requirements
+from shippinglabel.requirements import (
+		ComparableRequirement,
+		RequirementsManager,
+		combine_requirements,
+		read_requirements
+		)
 
 # this package
 import repo_helper
@@ -61,6 +67,7 @@ from repo_helper.blocks import (
 		)
 from repo_helper.configupdater2 import ConfigUpdater
 from repo_helper.files import management
+from repo_helper.files.pre_commit import make_github_url
 from repo_helper.templates import init_repo_template_dir, template_dir
 from repo_helper.utils import pformat_tabs, reformat_file
 
@@ -77,7 +84,6 @@ __all__ = [
 		"make_404_page",
 		"make_docs_source_rst",
 		"make_style",
-		"remove_autodoc_augment_defaults",
 		]
 
 # Disable logging from cssutils
@@ -88,17 +94,17 @@ logging.getLogger("CSSUTILS").addFilter(lambda record: False)
 
 class DocRequirementsManager(RequirementsManager):
 	target_requirements = {
-			Requirement("sphinxcontrib-httpdomain>=1.7.0"),
-			Requirement("sphinxemoji>=0.1.6"),
-			Requirement("sphinx-notfound-page>=0.5"),
-			Requirement("sphinx-tabs>=1.1.13"),
-			Requirement("autodocsumm>=0.2.0"),
-			# Requirement("sphinx-gitstamp"),
-			# Requirement("gitpython"),
-			# Requirement("sphinx_autodoc_typehints>=1.11.0"),
-			Requirement("sphinx-copybutton>=0.2.12"),
-			Requirement("sphinx-prompt>=1.1.0"),
-			Requirement("sphinx>=3.0.3"),
+			ComparableRequirement("sphinxcontrib-httpdomain>=1.7.0"),
+			ComparableRequirement("sphinxemoji>=0.1.6"),
+			ComparableRequirement("sphinx-notfound-page>=0.5"),
+			ComparableRequirement("sphinx-tabs>=1.1.13"),
+			ComparableRequirement("autodocsumm>=0.2.0"),
+			# ComparableRequirement("sphinx-gitstamp"),
+			# ComparableRequirement("gitpython"),
+			# ComparableRequirement("sphinx_autodoc_typehints>=1.11.0"),
+			ComparableRequirement("sphinx-copybutton>=0.2.12"),
+			ComparableRequirement("sphinx-prompt>=1.1.0"),
+			ComparableRequirement("sphinx>=3.0.3"),
 			}
 
 	def __init__(self, repo_path: PathLike, templates: jinja2.Environment):
@@ -106,44 +112,50 @@ class DocRequirementsManager(RequirementsManager):
 		self._globals = templates.globals
 		super().__init__(repo_path)
 
-	def compile_target_requirements(self) -> None:
-		# Mapping of pypi_name to version specifier
-		theme_versions = {
-				"alabaster": ">=0.7.12",
-				"sphinx_rtd_theme": "<0.5",
-				"domdf_sphinx_theme": ">=0.1.0",
-				"repo_helper_sphinx_theme": ">=0.0.2",
-				}
+	# Mapping of pypi_name to version specifier
+	theme_versions = {
+			"alabaster": ">=0.7.12",
+			"sphinx-rtd-theme": "<0.5",
+			"domdf-sphinx-theme": ">=0.1.0",
+			"repo-helper-sphinx_theme": ">=0.0.2",
+			"furo": ">=2020.11.19b18",
+			}
 
-		for name, specifier in theme_versions.items():
-			if name == self._globals["sphinx_html_theme"]:
-				self.target_requirements.add(Requirement(f"{name}{specifier}"))
+	def compile_target_requirements(self) -> None:
+
+		for name, specifier in self.theme_versions.items():
+			if normalize(name) == normalize(self._globals["sphinx_html_theme"]):
+				self.target_requirements.add(ComparableRequirement(f"{name}{specifier}"))
 				break
 		else:
-			self.target_requirements.add(Requirement(self._globals["sphinx_html_theme"]))
+			self.target_requirements.add(ComparableRequirement(normalize(self._globals["sphinx_html_theme"])))
 
 		# Mapping of pypi_name to version specifier
 		my_sphinx_extensions = {
-				"extras_require": ">=0.2.0",
-				"seed_intersphinx_mapping": ">=0.1.1",
-				"default_values": ">=0.2.0",
-				"toctree_plus": ">=0.0.4",
-				"sphinx-toolbox": ">=1.7.2",
+				"extras-require": ">=0.2.0",
+				"seed-intersphinx-mapping": ">=0.1.1",
+				"default-values": ">=0.2.0",
+				"toctree-plus": ">=0.0.4",
+				"sphinx-toolbox": ">=1.7.5",
 				}
 
 		for name, specifier in my_sphinx_extensions.items():
 			if name != self._globals["pypi_name"]:
-				self.target_requirements.add(Requirement(f"{name}{specifier}"))
+				self.target_requirements.add(ComparableRequirement(f"{name}{specifier}"))
 
 	def merge_requirements(self) -> List[str]:
-		current_requirements, comments = read_requirements(self.req_file)
+		current_requirements, comments, invalid_lines = read_requirements(self.req_file, include_invalid=True)
+
+		for line in invalid_lines:
+			if line.startswith("git+"):
+				comments.append(line)
+			else:
+				warnings.warn(f"Ignored invalid requirement {line!r}")
 
 		for req in current_requirements:
 			req.name = normalize(req.name)
-			if req.name not in self.get_target_requirement_names():
-				if req.name == "sphinx-rtd-theme" and self._globals["sphinx_html_theme"] == "domdf_sphinx_theme":
-					self.target_requirements.add(Requirement("domdf-sphinx-theme>=0.1.0"))
-				elif req.name == "sphinx-autodoc-typehints":
+			if req.name not in self.get_target_requirement_names() and req.name not in self.theme_versions.keys():
+				if req.name == "sphinx-autodoc-typehints":
 					continue
 				else:
 					self.target_requirements.add(req)
@@ -229,7 +241,7 @@ def make_docutils_conf(repo_path: pathlib.Path, templates: jinja2.Environment) -
 	file.parent.maybe_make(parents=True)
 
 	if not file.is_file():
-		file.write_text("\n".join([
+		file.write_text('\n'.join([
 				"[restructuredtext parser]",
 				"tab_width = 4",
 				'',
@@ -269,7 +281,7 @@ def make_conf(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[st
 	username = templates.globals["username"]
 	repo_name = templates.globals["repo_name"]
 
-	if templates.globals["sphinx_html_theme"] in {"sphinx_rtd_theme", "domdf_sphinx_theme"}:
+	if templates.globals["sphinx_html_theme"] in {"sphinx-rtd-theme", "domdf-sphinx-theme"}:
 		for key, val in {
 			"display_github": True,  # Integrate GitHub
 			"github_user": username,  # Username
@@ -287,7 +299,7 @@ def make_conf(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[st
 			if key not in templates.globals["html_theme_options"]:
 				templates.globals["html_theme_options"][key] = val
 
-	elif templates.globals["sphinx_html_theme"] in {"alabaster", "repo_helper_sphinx_theme"}:
+	elif templates.globals["sphinx_html_theme"] in {"alabaster", "repo-helper-sphinx-theme"}:
 		# See https://github.com/bitprophet/alabaster/blob/master/alabaster/theme.conf
 		# and https://alabaster.readthedocs.io/en/latest/customization.html
 		for key, val in {
@@ -306,6 +318,28 @@ def make_conf(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[st
 			if key not in templates.globals["html_theme_options"]:
 				templates.globals["html_theme_options"][key] = val
 
+	elif templates.globals["sphinx_html_theme"] in {"furo"}:
+		# See https://github.com/bitprophet/alabaster/blob/master/alabaster/theme.conf
+		# and https://alabaster.readthedocs.io/en/latest/customization.html
+		for key, val in {
+			"light_css_variables": {
+			"toc-title-font-size": "12pt",
+			"toc-font-size": "12pt",
+			"admonition-font-size": "12pt",
+			},
+			"dark_css_variables": {
+			"toc-title-font-size": "12pt",
+			"toc-font-size": "12pt",
+			"admonition-font-size": "12pt",
+			},
+			}.items():
+			if key not in templates.globals["html_theme_options"]:
+				templates.globals["html_theme_options"][key] = val
+			else:
+				templates.globals["html_theme_options"][key] = {
+						**val, **templates.globals["html_theme_options"][key]
+						}
+
 	sphinx_extensions = [
 			"sphinx_toolbox",
 			"sphinx_toolbox.more_autodoc",
@@ -343,8 +377,18 @@ def make_conf(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[st
 
 
 class StyleSheet(css.CSSStyleSheet):
+	"""
+	Represents a CSS style sheet.
+	"""
+
+	def add_style(self, selector: str, styles: Dict[str, Union[Sequence, str, int, None]]) -> None:
+		"""
+		Add a style to the stylesheet.
+
+		:param selector:
+		:param styles:
+		"""
 
-	def add_style(self, selector: str, styles: Dict[str, Union[Sequence, str, int, None]]):
 		self.add(make_style(selector, styles))
 
 
@@ -363,7 +407,7 @@ def make_alabaster_theming() -> str:
 	# Formatting preferences
 	css_parser.ser.prefs.omitLastSemicolon = False
 	css_parser.ser.prefs.indentClosingBrace = False
-	css_parser.ser.prefs.indent = "	"
+	css_parser.ser.prefs.indent = '\t'
 
 	# Helpers
 	important = "important"
@@ -449,16 +493,16 @@ def make_alabaster_theming() -> str:
 	# No end-of-line hyphenation
 	sheet.add_style("div.body p, ol > li, div.body td", {"hyphens": None})
 
-	sheet.add_style("img, div.figure", {"margin": ("0", important)})
+	sheet.add_style("img, div.figure", {"margin": ('0', important)})
 	sheet.add_style("ul > li", {"text-align": "justify"})
-	sheet.add_style("ul > li > p", {"margin-bottom": "0"})
-	sheet.add_style("ol > li > p", {"margin-bottom": "0"})
+	sheet.add_style("ul > li > p", {"margin-bottom": '0'})
+	sheet.add_style("ol > li > p", {"margin-bottom": '0'})
 	sheet.add_style("div.body code.descclassname", {"display": None})
 	sheet.add_style(".wy-table-responsive table td", {"white-space": ("normal", important)})
 	sheet.add_style(".wy-table-responsive", {"overflow": ("visible", important)})
 	sheet.add_style("div.toctree-wrapper.compound > ul > li", {
-			"margin": "0",
-			"padding": "0",
+			"margin": '0',
+			"padding": '0',
 			})
 	# TODO
 	# code.docutils.literal {{
@@ -466,7 +510,7 @@ def make_alabaster_theming() -> str:
 	#     padding: 0 1px;
 	# }}
 
-	stylesheet = sheet.cssText.decode("UTF-8").replace("}", "}\n")
+	stylesheet = sheet.cssText.decode("UTF-8").replace('}', "}\n")
 
 	# Reset CSS Parser to defaults
 	css_parser.ser.prefs.useDefaults()
@@ -497,7 +541,7 @@ def make_readthedocs_theming() -> str:
 	# Formatting preferences
 	css_parser.ser.prefs.omitLastSemicolon = False
 	css_parser.ser.prefs.indentClosingBrace = False
-	css_parser.ser.prefs.indent = "	"
+	css_parser.ser.prefs.indent = '\t'
 
 	# Helpers
 	important = "important"
@@ -514,7 +558,7 @@ def make_readthedocs_theming() -> str:
 	# Smooth scrolling between sections
 	sheet.add_style("html", {"scroll-behavior": "smooth"})
 
-	stylesheet = sheet.cssText.decode("UTF-8").replace("}", "}\n")
+	stylesheet = sheet.cssText.decode("UTF-8").replace('}', "}\n")
 
 	# Reset CSS Parser to defaults
 	css_parser.ser.prefs.useDefaults()
@@ -533,11 +577,13 @@ def copy_docs_styling(repo_path: pathlib.Path, templates: jinja2.Environment) ->
 	docs_dir = PathPlus(repo_path / templates.globals["docs_dir"])
 	style_css = docs_dir / "_static" / "style.css"
 	layout_html = docs_dir / "_templates" / "layout.html"
+	base_html = docs_dir / "_templates" / "base.html"
+	furo_navigation = docs_dir / "_templates" / "sidebar" / "navigation.html"
 
 	for directory in {style_css.parent, layout_html.parent}:
 		directory.maybe_make(parents=True)
 
-	if templates.globals["sphinx_html_theme"] == "sphinx_rtd_theme":
+	if templates.globals["sphinx_html_theme"] == "sphinx-rtd-theme":
 
 		style_css.write_lines([
 				f"/* {templates.globals['managed_message']} */",
@@ -550,21 +596,81 @@ def copy_docs_styling(repo_path: pathlib.Path, templates: jinja2.Environment) ->
 				'',
 				make_alabaster_theming(),
 				])
+	elif templates.globals["sphinx_html_theme"] == "furo":
+		style_css.write_lines([
+				f"/* {templates.globals['managed_message']} */",
+				'',
+				"div.highlight {",
+				"    -moz-tab-size: 4; /* Firefox */",
+				"    tab-size: 4;",
+				'}',
+				])
 	else:
 		style_css.write_clean('')
 
-	layout_html.write_lines([
-			f"<!--- {templates.globals['managed_message']} --->",
-			'{% extends "!layout.html" %}',
-			"{% block extrahead %}",
-			'	<link href="{{ pathto("_static/style.css", True) }}" rel="stylesheet" type="text/css">',
-			"{% endblock %}",
-			''
-			])
+	if templates.globals["sphinx_html_theme"] == "furo":
+		furo_navigation.parent.maybe_make()
+		github_url = make_github_url(templates.globals["username"], templates.globals["repo_name"])
+
+		buf = [
+				"<!---{managed_message}--->".format_map(templates.globals),
+				dedent(
+						"""\
+<div class="sidebar-tree">
+  {{ furo_navigation_tree }}
+</div>
+
+<div class="sidebar-tree">
+  <p class="caption"><span class="caption-text">Links</span></p>
+  <ul>"""
+						)
+				]
+
+		buf.append(f'    <li class="toctree-l1"><a class="reference external" href="{github_url}">GitHub</a></li>')
+
+		if templates.globals["on_pypi"]:
+			buf.append(
+					f'    <li class="toctree-l1"><a class="reference external" '
+					f'href="https://pypi.org/project/{templates.globals["pypi_name"]}">PyPI</a></li>'
+					)
+
+		buf.append(dedent("  </ul>\n</div>\n"))
+
+		furo_navigation.write_lines(buf)
+
+		base_html.write_lines([
+				f"<!--- {templates.globals['managed_message']} --->",
+				'{% extends "!base.html" %}',
+				"{% block extrahead %}",
+				'\t<link href="{{ pathto("_static/style.css", True) }}" rel="stylesheet" type="text/css">',
+				"{% endblock %}",
+				''
+				])
+
+		layout_html.unlink(missing_ok=True)
+
+	else:
+		try:
+			shutil.rmtree(furo_navigation.parent)
+		except FileNotFoundError:
+			pass
+
+		layout_html.write_lines([
+				f"<!--- {templates.globals['managed_message']} --->",
+				'{% extends "!layout.html" %}',
+				"{% block extrahead %}",
+				'\t<link href="{{ pathto("_static/style.css", True) }}" rel="stylesheet" type="text/css">',
+				"{% endblock %}",
+				''
+				])
+
+		base_html.unlink(missing_ok=True)
 
 	return [
 			style_css.relative_to(repo_path).as_posix(),
 			layout_html.relative_to(repo_path).as_posix(),
+			base_html.relative_to(repo_path).as_posix(),
+			furo_navigation.relative_to(repo_path).as_posix(),
 			]
 
 
@@ -587,9 +693,8 @@ def rewrite_docs_index(repo_path: pathlib.Path, templates: jinja2.Environment) -
 			repo_name=templates.globals["repo_name"],
 			version=templates.globals["version"],
 			conda=templates.globals["enable_conda"],
-			tests=templates.globals["enable_tests"],
+			tests=templates.globals["enable_tests"] and not templates.globals["stubs_package"],
 			docs=templates.globals["enable_docs"],
-			travis_site=templates.globals["travis_site"],
 			pypi_name=templates.globals["pypi_name"],
 			docker_shields=templates.globals["docker_shields"],
 			docker_name=templates.globals["docker_name"],
@@ -611,7 +716,7 @@ def rewrite_docs_index(repo_path: pathlib.Path, templates: jinja2.Environment) -
 			templates.globals["on_pypi"],
 			templates.globals["pypi_name"],
 			templates.globals["conda_channels"],
-			)
+			) + '\n'
 
 	links_block = create_docs_links_block(
 			templates.globals["username"],
@@ -704,20 +809,3 @@ def make_style(selector: str, styles: Dict[str, Union[Sequence, str, int, None]]
 			style[name] = str(properties)
 
 	return css.CSSStyleRule(selectorText=selector, style=style)
-
-
-@management.register("autodoc_augment_defaults", ["enable_docs"])
-def remove_autodoc_augment_defaults(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
-	"""
-	Remove the redundant "autodoc_augment_defaults" extension.
-
-	:param repo_path: Path to the repository root.
-	:param templates:
-	"""
-
-	target_file = PathPlus(repo_path / templates.globals["docs_dir"] / "autodoc_augment_defaults.py")
-
-	if target_file.is_file():
-		target_file.unlink()
-
-	return [target_file.relative_to(repo_path).as_posix()]
