@@ -42,7 +42,7 @@ from shippinglabel.requirements import combine_requirements
 import repo_helper.files
 from repo_helper.configupdater2 import ConfigUpdater
 from repo_helper.files import management
-from repo_helper.utils import IniConfigurator, indent_with_tab, reformat_file
+from repo_helper.utils import IniConfigurator, indent_join, indent_with_tab, reformat_file
 
 __all__ = [
 		"make_manifest",
@@ -87,7 +87,7 @@ def make_manifest(repo_path: pathlib.Path, templates: jinja2.Environment) -> Lis
 			f"include {pkg_dir / 'py.typed'}",
 			])
 
-	file.write_clean("\n".join(manifest_entries))
+	file.write_clean('\n'.join(manifest_entries))
 
 	return [file.name]
 
@@ -167,9 +167,12 @@ def make_setup(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[s
 	data["description"] = repr(templates.globals["short_desc"])
 	data["py_modules"] = templates.globals["py_modules"]
 
+	if templates.globals["desktopfile"]:
+		data["data_files"] = "[('share/applications', ['{modname}.desktop'])]".format_map(templates.globals)
+
 	setup_args = sorted({**data, **templates.globals["additional_setup_args"]}.items())
 
-	setup_file.write_clean(setup.render(additional_setup_args="\n".join(f"\t\t{k}={v}," for k, v in setup_args)))
+	setup_file.write_clean(setup.render(additional_setup_args='\n'.join(f"\t\t{k}={v}," for k, v in setup_args)))
 
 	with importlib_resources.path(repo_helper.files, "isort.cfg") as isort_config:
 		yapf_style = PathPlus(isort_config).parent.parent / "templates" / "style.yapf"
@@ -231,7 +234,7 @@ class SetupCfgConfig(IniConfigurator):
 		if self["enable_docs"]:
 			project_urls.insert(0, "Documentation = https://{repo_name}.readthedocs.io".format_map(self._globals))
 
-		self._ini["metadata"]["project_urls"] = indent_with_tab("\n" + textwrap.dedent("\n".join(project_urls)))
+		self._ini["metadata"]["project_urls"] = indent_with_tab('\n' + textwrap.dedent('\n'.join(project_urls)))
 		self._ini["metadata"]["classifiers"] = self["classifiers"]
 
 	def options(self):
@@ -257,13 +260,8 @@ class SetupCfgConfig(IniConfigurator):
 		``[options.packages.find]``.
 		"""
 
-		self._ini["options.packages.find"]["exclude"] = indent_with_tab(
-				textwrap.dedent("""
-{tests_dir}
-{tests_dir}.*
-{docs_dir}
-""".format_map(self._globals))
-				)
+		excludes = [self["tests_dir"], f"{self['tests_dir']}.*", self["docs_dir"]]
+		self._ini["options.packages.find"]["exclude"] = indent_join(sorted(set(excludes)))
 
 	def options_entry_points(self):
 		"""
@@ -293,7 +291,21 @@ class SetupCfgConfig(IniConfigurator):
 		if ini_file.is_file():
 			existing_config = ConfigUpdater()
 			existing_config.read(str(ini_file))
+
+			def strip(string: str) -> str:
+				return string.strip()
+
 			for section in existing_config.sections_blocks():
+				if section.name == "options.packages.find" and "exclude" in section:
+
+					all_excludes = (
+							*section["exclude"].value.splitlines(),
+							*self._ini["options.packages.find"]["exclude"].value.splitlines(),
+							)
+
+					exclude_packages = sorted(set(filter(bool, map(strip, all_excludes))))
+					self._ini["options.packages.find"]["exclude"] = indent_join(exclude_packages)
+
 				if section.name not in self.managed_sections:
 					self._ini.add_section(section)
 				elif section.name == "mypy" and "incremental" in section:
