@@ -137,6 +137,10 @@ class Repo:
 	hooks: List[Hook] = attr.ib(converter=_hook_converter)
 
 	def to_dict(self) -> MutableMapping[str, Union[str, List[Hook]]]:
+		"""
+		Returns a dictionary representation of the :class:`~.Repo`.
+		"""
+
 		return {
 				"repo": str(self.repo),
 				"rev": self.rev,
@@ -169,13 +173,13 @@ pre_commit_hooks = Repo(
 
 pygrep_hooks = Repo(
 		repo=make_github_url("pre-commit", "pygrep-hooks"),
-		rev="v1.5.1",
+		rev="v1.7.0",
 		hooks=["python-no-eval"],
 		)
 
 pyupgrade = Repo(
 		repo=make_github_url("asottile", "pyupgrade"),
-		rev="v2.7.3",
+		rev="v2.7.4",
 		hooks=[{"id": "pyupgrade", "args": ["--py36-plus"]}]
 		)
 
@@ -225,7 +229,7 @@ def make_pre_commit(repo_path: pathlib.Path, templates: jinja2.Environment) -> L
 
 	domdfcoding_hooks = Repo(
 			repo=make_github_url("domdfcoding", "pre-commit-hooks"),
-			rev="v0.1.4",
+			rev="v0.1.6",
 			hooks=[
 					{"id": "requirements-txt-sorter", "args": ["--allow-git"]},
 					{
@@ -238,7 +242,7 @@ def make_pre_commit(repo_path: pathlib.Path, templates: jinja2.Environment) -> L
 
 	flake8_dunder_all = Repo(
 			repo=make_github_url("domdfcoding", "flake8-dunder-all"),
-			rev="v0.1.0",
+			rev="v0.1.3",
 			hooks=[{
 					"id": "ensure-dunder-all",
 					"files": fr"^{import_name}{'-stubs' if stubs_package else ''}/.*\.py$"
@@ -249,14 +253,19 @@ def make_pre_commit(repo_path: pathlib.Path, templates: jinja2.Environment) -> L
 
 	yapf_isort = Repo(
 			repo=make_github_url("domdfcoding", "yapf-isort"),
-			rev="v0.5.1",
+			rev="v0.5.4",
 			hooks=[{"id": "yapf-isort", "exclude": yapf_isort_excludes}],
 			)
 
+	dep_checker_args = [templates.globals["import_name"].replace('.', '/')]
+
+	if templates.globals["source_dir"]:
+		dep_checker_args.extend(["--work-dir", templates.globals["source_dir"]])
+
 	dep_checker = Repo(
 			repo=make_github_url("domdfcoding", "dep_checker"),
-			rev="v0.3.1",
-			hooks=[{"id": "dep_checker", "args": [templates.globals["import_name"].replace(".", "/")]}]
+			rev="v0.4.1",
+			hooks=[{"id": "dep_checker", "args": dep_checker_args}]
 			)
 
 	pre_commit_file = PathPlus(repo_path / ".pre-commit-config.yaml")
@@ -286,8 +295,11 @@ def make_pre_commit(repo_path: pathlib.Path, templates: jinja2.Environment) -> L
 			pyupgrade,
 			lucas_c_hooks,
 			yapf_isort,
-			dep_checker,
 			]
+
+	if not templates.globals["stubs_package"]:
+		managed_hooks.append(dep_checker)
+
 	managed_hooks_urls = [str(hook.repo) for hook in managed_hooks]
 
 	custom_hooks_comment = "# Custom hooks can be added below this comment"
