@@ -28,15 +28,20 @@ import os.path
 import pathlib
 import posixpath
 import re
+import warnings
 from typing import Any, List
 
 # 3rd party
 import jinja2
 from domdf_python_tools.paths import PathPlus
 from domdf_python_tools.typing import PathLike
-from packaging.requirements import Requirement
 from shippinglabel import normalize
-from shippinglabel.requirements import RequirementsManager, read_requirements
+from shippinglabel.requirements import (
+		ComparableRequirement,
+		RequirementsManager,
+		combine_requirements,
+		read_requirements
+		)
 
 # this package
 from repo_helper.configupdater2 import ConfigUpdater
@@ -67,7 +72,6 @@ class ToxConfig(IniConfigurator):
 	managed_sections = [
 			"tox",
 			"envlists",
-			"travis",
 			"gh-actions",
 			"testenv",
 			"testenv:docs",
@@ -85,6 +89,13 @@ class ToxConfig(IniConfigurator):
 
 	def __init__(self, repo_path: pathlib.Path, templates: jinja2.Environment):
 		self._globals = templates.globals
+
+		self.managed_sections = self.managed_sections[:]
+
+		for section_name in self["tox_unmanaged"]:
+			if section_name in self.managed_sections:
+				del self.managed_sections[self.managed_sections.index(section_name)]
+
 		super().__init__(base_path=repo_path)
 
 	def __getitem__(self, item: str) -> Any:
@@ -118,7 +129,7 @@ class ToxConfig(IniConfigurator):
 		else:
 			directory = posixpath.join(
 					self._globals["source_dir"],
-					self._globals["import_name"].replace(".", "/"),
+					self._globals["import_name"].replace('.', '/'),
 					)
 			source_files.append(directory)
 
@@ -161,7 +172,7 @@ class ToxConfig(IniConfigurator):
 			commands.append("mypy tests")
 		elif self["stubs_package"]:
 			commands.append(f"stubtest {self['import_name']} {{posargs}}")
-		elif self["enable_tests"]:
+		else:
 			commands.append(f"mypy {' '.join(self.get_source_files())} {{posargs}}")
 
 		return commands
@@ -186,14 +197,6 @@ class ToxConfig(IniConfigurator):
 		if self["enable_tests"]:
 			self._ini["envlists"]["cov"] = [self["tox_py_versions"][0], "coverage"]
 
-	def travis(self):
-		"""
-		``[travis]``.
-		"""
-
-		versions = (f"{py_ver}: {tox_py_ver}" for py_ver, tox_py_ver in self["tox_travis_versions"].items())
-		self._ini["travis"]["python"] = indent_join(versions)
-
 	def gh_actions(self):
 		"""
 		``[gh-actions]``.
@@ -240,7 +243,9 @@ class ToxConfig(IniConfigurator):
 		"""
 
 		if self["enable_docs"]:
-			self._ini["testenv:docs"]["setenv"] = "SHOW_TODOS = 1"
+			envvars = ["SHOW_TODOS = 1"]  # , "PIP_USE_FEATURE = 2020-resolver"
+			self._ini["testenv:docs"]["setenv"] = indent_join(envvars)
+
 			self._ini["testenv:docs"]["basepython"] = "python3.8"
 			self._ini["testenv:docs"]["changedir"] = f"{{toxinidir}}/{self['docs_dir']}"
 
@@ -294,6 +299,7 @@ class ToxConfig(IniConfigurator):
 				"flake8-builtins>=1.5.3",
 				"flake8-docstrings>=1.5.0",
 				"flake8-dunder-all>=0.1.1",
+				"flake8-github-actions>=0.1.0",
 				"flake8-pyi>=20.10.0",
 				"flake8-pytest-style>=1.3.0",
 				"flake8-sphinx-links>=0.0.4",
@@ -302,11 +308,11 @@ class ToxConfig(IniConfigurator):
 				"git+https://github.com/PyCQA/pydocstyle@5118faa7173b0e5bbc230c4adf628758e13605bf",
 				"git+https://github.com/domdfcoding/flake8-quotes.git",
 				"git+https://github.com/domdfcoding/flake8-rst-docstrings.git",
-				"git+https://github.com/domdfcoding/flake8-rst-docstrings-sphinx.git",
+				"git+https://github.com/domdfcoding/flake8-rst-docstrings-sphinx.git@v2",
 				"pygments>=2.7.1",
 				])
 		# cmd = f"flake8 {' '.join(self.get_source_files())} --format=rst-toolbox"
-		cmd = f"python3 -m flake8_rst_docstrings_sphinx {' '.join(self.get_source_files())} --allow-toolbox"
+		cmd = f"python3 -m flake8_rst_docstrings_sphinx {' '.join(self.get_source_files())} --allow-toolbox {{posargs}}"
 		self._ini["testenv:lint"]["commands"] = cmd
 
 	def testenv_mypy(self):
@@ -314,7 +320,7 @@ class ToxConfig(IniConfigurator):
 		``[testenv:mypy]``.
 		"""
 
-		if self["stubs_package"] or self["enable_tests"]:
+		if not (self["stubs_package"] and not self["enable_tests"]):
 			self._ini["testenv:mypy"]["basepython"] = "python{python_deploy_version}".format(**self._globals)
 			self._ini["testenv:mypy"]["ignore_errors"] = True
 			self._ini["testenv:mypy"]["changedir"] = "{toxinidir}"
@@ -381,11 +387,11 @@ class ToxConfig(IniConfigurator):
 		"""
 
 		self._ini["flake8"]["max-line-length"] = "120"
-		self._ini["flake8"]["select"] = " ".join(
+		self._ini["flake8"]["select"] = ' '.join(
 				str(x) for x in lint_fix_list + lint_warn_list + code_only_warning
 				)
 
-		excludes = f".git,__pycache__,{self['docs_dir']},old,build,dist,make_conda_recipe.py,__pkginfo__.py,setup.py"
+		excludes = f".git,__pycache__,{self['docs_dir']},old,build,dist,make_conda_recipe.py,__pkginfo__.py,setup.py,.tox,venv"
 		self._ini["flake8"]["exclude"] = excludes
 		# self._ini["flake8"]["rst-roles"] = indent_join(sorted(allowed_rst_roles))
 		self._ini["flake8"]["rst-directives"] = indent_join(sorted(allowed_rst_directives))
@@ -470,6 +476,11 @@ class ToxConfig(IniConfigurator):
 		self._ini["pytest"]["timeout"] = 300
 
 	def merge_existing(self, ini_file):
+		"""
+		Merge existing sections in the configuration file into the new configuration.
+
+		:param ini_file: The existing ``.ini`` file.
+		"""
 
 		if ini_file.is_file():
 			existing_config = ConfigUpdater()
@@ -545,7 +556,7 @@ def make_isort(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[s
 
 	isort["settings"]["line_length"] = 115
 	isort["settings"]["force_to_top"] = True
-	isort["settings"]["indent"] = '"		"'  # To match what yapf uses
+	isort["settings"]["indent"] = '"\t\t"'  # To match what yapf uses
 
 	# Undocumented 8th option with the closing bracket indented
 	isort["settings"]["multi_line_output"] = 8
@@ -559,12 +570,14 @@ def make_isort(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[s
 	# isort["settings"]["float_to_top"] = True  # TODO: Doesn't work properly; No imports get sorted or floated to the top
 	isort["settings"]["remove_redundant_aliases"] = True
 	isort["settings"]["default_section"] = "THIRDPARTY"
-	# isort["settings"]["no_lines_before"] = "LOCALFOLDER"
 	if "float_to_top" in isort["settings"]:
 		del isort["settings"]["float_to_top"]
 
 	if templates.globals["enable_tests"]:
-		test_requirements = read_requirements(repo_path / templates.globals["tests_dir"] / "requirements.txt")[0]
+		test_requirements = read_requirements(
+				repo_path / templates.globals["tests_dir"] / "requirements.txt",
+				include_invalid=True,
+				)[0]
 	else:
 		test_requirements = set()
 
@@ -585,7 +598,8 @@ def make_isort(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[s
 	all_requirements.discard(templates.globals["import_name"])
 	all_requirements.discard("iniconfig")
 
-	isort["settings"]["known_third_party"] = sorted({"github", "requests", *all_requirements})
+	known_third_party = [req.replace('-', '_') for req in sorted({"github", "requests", *all_requirements})]
+	isort["settings"]["known_third_party"] = known_third_party
 	isort["settings"]["known_first_party"] = templates.globals["import_name"]
 
 	isort_file.write_clean(str(isort))
@@ -595,12 +609,12 @@ def make_isort(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[s
 
 class TestsRequirementsManager(RequirementsManager):
 	target_requirements = {
-			Requirement("coverage>=5.1"),
-			Requirement("pytest>=6.0.0"),
-			Requirement("pytest-cov>=2.8.1"),
-			Requirement("pytest-randomly>=3.3.1"),
-			Requirement("pytest-timeout>=1.4.2"),  # Requirement("pytest-rerunfailures>=9.0"),
-			Requirement("iniconfig!=1.1.0,>=1.0.1"),
+			ComparableRequirement("coverage>=5.1"),
+			ComparableRequirement("pytest>=6.0.0"),
+			ComparableRequirement("pytest-cov>=2.8.1"),
+			ComparableRequirement("pytest-randomly>=3.3.1"),
+			ComparableRequirement("pytest-timeout>=1.4.2"),  # ComparableRequirement("pytest-rerunfailures>=9.0"),
+			ComparableRequirement("iniconfig!=1.1.0,>=1.0.1"),
 			}
 
 	def __init__(self, repo_path: PathLike, templates: jinja2.Environment):
@@ -610,9 +624,22 @@ class TestsRequirementsManager(RequirementsManager):
 
 	def compile_target_requirements(self) -> None:
 		if self._globals["pypi_name"] != "coverage_pyver_pragma":
-			self.target_requirements.add(Requirement("coverage-pyver-pragma>=0.0.6"))
+			self.target_requirements.add(ComparableRequirement("coverage-pyver-pragma>=0.0.6"))
 		if self._globals["pypi_name"] != "domdf_python_tools":
-			self.target_requirements.add(Requirement("domdf-python-tools[testing]>=1.5.0"))
+			self.target_requirements.add(ComparableRequirement("domdf-python-tools[testing]>=1.5.0"))
+
+	def merge_requirements(self) -> List[str]:
+		current_requirements, comments, invalid_lines = read_requirements(self.req_file, include_invalid=True)
+
+		for line in invalid_lines:
+			if line.startswith("git+"):
+				comments.append(line)
+			else:
+				warnings.warn(f"Ignored invalid requirement {line!r}")
+
+		self.target_requirements = set(combine_requirements(*current_requirements, *self.target_requirements))
+
+		return comments
 
 
 @management.register("test_requirements", ["enable_tests"])
