@@ -28,13 +28,16 @@ General utilities.
 #
 
 # stdlib
+import datetime
+import os
 import pathlib
 import re
 import textwrap
 from datetime import date, timedelta
-from typing import TYPE_CHECKING, Callable, Dict, Iterable, List, Optional, TypeVar
+from typing import TYPE_CHECKING, Callable, Dict, Iterable, List, Optional, TypeVar, Union
 
 # 3rd party
+import dulwich.repo
 import isort  # type: ignore
 import isort.settings  # type: ignore
 import yapf_isort
@@ -44,7 +47,9 @@ from domdf_python_tools.paths import PathPlus
 from domdf_python_tools.pretty_print import FancyPrinter
 from domdf_python_tools.stringlist import StringList
 from domdf_python_tools.typing import PathLike
+from dulwich.porcelain import open_repo_closing
 from shippinglabel import normalize
+from southwark import status
 
 # this package
 from repo_helper.configupdater2 import ConfigUpdater
@@ -68,6 +73,8 @@ __all__ = [
 		"today",
 		"traverse_to_file",
 		"sort_paths",
+		"commit_changes",
+		"stage_changes",
 		]
 
 #: Under normal circumstances returns :meth:`datetime.date.today`.
@@ -89,7 +96,7 @@ def indent_with_tab(
 		to all non-empty lines that do not consist solely of whitespace characters.
 	"""
 
-	return textwrap.indent(text, "\t" * depth, predicate=predicate)
+	return textwrap.indent(text, '\t' * depth, predicate=predicate)
 
 
 def pformat_tabs(
@@ -260,7 +267,7 @@ def indent_join(iterable: Iterable[str]) -> str:
 	if len(iterable) > 1:
 		if not iterable[0] == '':
 			iterable.insert(0, '')
-	return indent_with_tab(textwrap.dedent("\n".join(iterable)))
+	return indent_with_tab(textwrap.dedent('\n'.join(iterable)))
 
 
 class IniConfigurator:
@@ -285,13 +292,20 @@ class IniConfigurator:
 				"# You may add new sections, but any changes made to the following sections will be lost:",
 				])
 
+		self.managed_sections = self.managed_sections[:]
+
 		for sec in self.managed_sections:
 			self._ini.add_section(sec)
 			self._output.append(f"#     * {sec}")
 
 		self._output.blankline(ensure_single=True)
 
-	def merge_existing(self, ini_file):
+	def merge_existing(self, ini_file: pathlib.Path):
+		"""
+		Merge existing sections in the configuration file into the new configuration.
+
+		:param ini_file: The existing ``.ini`` file.
+		"""
 
 		if ini_file.is_file():
 			existing_config = ConfigUpdater()
@@ -308,40 +322,14 @@ class IniConfigurator:
 		ini_file = PathPlus(self.base_path / self.filename)
 
 		for section_name in self.managed_sections:
-			getattr(self, re.sub("[:.-]", "_", section_name))()
+			getattr(self, re.sub("[:.-]", '_', section_name))()
 
 		self.merge_existing(ini_file)
 		self._output.append(str(self._ini))
 		ini_file.write_lines(self._output)
 
 
-_P = TypeVar("_P", bound=pathlib.Path)
-
-
-def traverse_to_file(base_directory: _P, *filename: PathLike, height: int = -1) -> _P:
-	r"""
-	Traverse the parents of the given directory until the desired file is found.
-
-	:param base_directory: The directory to start searching from
-	:param \*filename: The filename(s) to search for
-	:param height: The maximum height to traverse to.
-	"""
-
-	if not filename:
-		raise TypeError("traverse_to_file expected 2 or more arguments, got 1")
-
-	for level, directory in enumerate((base_directory, *base_directory.parents)):
-		if height > 0 and ((level - 1) > height):
-			break
-
-		for file in filename:
-			if (directory / file).is_file():
-				return directory
-
-	raise FileNotFoundError(f"'{filename[0]!s}' not found in {base_directory}")
-
-
-def easter_egg() -> None:  # noqa: D102  # pragma: no cover
+def easter_egg() -> None:  # noqa: D102,D103  # pragma: no cover
 	easter = calc_easter(today.year)
 	easter_margin = timedelta(days=7)
 
@@ -351,6 +339,8 @@ def easter_egg() -> None:  # noqa: D102  # pragma: no cover
 		print("🎃 👻 🦇")
 	elif today == date(today.year, 11, 5):
 		print("🎆 🔥 🚀")
+	elif today == date(today.year, 11, 11):
+		print("We will remember them.")
 	elif today.month == 12:
 		print("🎅 ☃️ 🎁")
 
@@ -394,3 +384,69 @@ def sort_paths(*paths: PathLike) -> List[PathPlus]:
 		files.extend(PathPlus(directory) / path for path in sort_paths(*contents))
 
 	return files + sorted(local_contents)
+
+
+def stage_changes(
+		repo: Union[PathLike, dulwich.repo.Repo],
+		files: Iterable[PathLike],
+		) -> List[PathPlus]:
+	"""
+	Stage any files that have been updated, added or removed.
+
+	:param repo: The repository.
+	:param files: List of files to stage.
+
+	:returns: A list of staged files.
+		Not all files in ``files`` will have been changed, and only changes are staged.
+
+	.. versionadded:: 2020.11.23
+	"""
+
+	with open_repo_closing(repo) as repo:
+		stat = status(repo)
+		unstaged_changes = stat.unstaged
+		untracked_files = stat.untracked
+
+		staged_files = []
+
+		for filename in files:
+			filename = PathPlus(filename)
+
+			if filename in unstaged_changes or filename in untracked_files:
+				repo.stage(os.path.normpath(filename))
+				staged_files.append(filename)
+			elif (
+					filename in stat.staged["add"] or filename in stat.staged["modify"]
+					or filename in stat.staged["delete"]
+					):
+				staged_files.append(filename)
+
+	return staged_files
+
+
+def commit_changes(
+		repo: Union[PathLike, dulwich.repo.Repo],
+		message: str = "Updated files with 'repo_helper'.",
+		) -> str:
+	"""
+	Commit staged changes.
+
+	:param repo: The repository to commit in.
+	:param message: The commit message to use.
+
+	:returns: The SHA of the commit.
+
+	.. versionadded:: 2020.11.23
+	"""
+
+	with open_repo_closing(repo) as repo:
+		current_time = datetime.datetime.now(datetime.timezone.utc).astimezone()
+		current_timezone = current_time.tzinfo.utcoffset(None).total_seconds()  # type: ignore
+
+		commit_sha = repo.do_commit(
+				message=message.encode("UTF-8"),
+				commit_timestamp=current_time.timestamp(),
+				commit_timezone=current_timezone,
+				)
+
+		return commit_sha.decode("UTF-8")
